==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetJourneyRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetJourneyRequest(
    applicationId: __string,
    journeyId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest = {
    import GetJourneyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .journeyId(__string.unwrap(journeyId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly =
    zio.aws.pinpoint.model.GetJourneyRequest.wrap(buildAwsValue())
}
object GetJourneyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetJourneyRequest =
      zio.aws.pinpoint.model.GetJourneyRequest(applicationId, journeyId)
    def applicationId: __string
    def journeyId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getJourneyId: ZIO[Any, Nothing, __string] = ZIO.succeed(journeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ) extends zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val journeyId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.journeyId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ): zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetJourneyRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetJourneyRequest(
    applicationId: __string,
    journeyId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest = {
    import GetJourneyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .journeyId(journeyId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly =
    zio.aws.pinpoint.model.GetJourneyRequest.wrap(buildAwsValue())
}
object GetJourneyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetJourneyRequest =
      zio.aws.pinpoint.model.GetJourneyRequest(applicationId, journeyId)
    def applicationId: __string
    def journeyId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getJourneyId: ZIO[Any, Nothing, __string] = ZIO.succeed(journeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ) extends zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val journeyId: __string = impl.journeyId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetJourneyRequest
  ): zio.aws.pinpoint.model.GetJourneyRequest.ReadOnly = new Wrapper(impl)
}
